==> webservices-osgi-2.4.4-sources.jar: com/sun/xml/ws/resources/BindingApiMessages.java <==
/*
 * Copyright (c) 1997, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package com.sun.xml.ws.resources;

import java.util.Locale;
import java.util.ResourceBundle;
import com.sun.istack.localization.Localizable;
import com.sun.istack.localization.LocalizableMessageFactory;
import com.sun.istack.localization.LocalizableMessageFactory.ResourceBundleSupplier;
import com.sun.istack.localization.Localizer;


/**
 * Defines string formatting method for each constant in the resource file
 * 
 */
public final class BindingApiMessages {

    private final static String BUNDLE_NAME = "com.sun.xml.ws.resources.bindingApi";
    private final static LocalizableMessageFactory MESSAGE_FACTORY = new LocalizableMessageFactory(BUNDLE_NAME, new BindingApiMessages.BundleSupplier());
    private final static Localizer LOCALIZER = new Localizer();

    public static Localizable localizableBINDING_API_NO_FAULT_MESSAGE_NAME() {
        return MESSAGE_FACTORY.getMessage("binding.api.no.fault.message.name");
    }

    /**
     * Fault message name must not be null.
     * 
     */
    public static String BINDING_API_NO_FAULT_MESSAGE_NAME() {
        return LOCALIZER.localize(localizableBINDING_API_NO_FAULT_MESSAGE_NAME());
    }

    private static class BundleSupplier
        implements ResourceBundleSupplier
    {


        public ResourceBundle getResourceBundle(Locale locale) {
            return ResourceBundle.getBundle(BUNDLE_NAME, locale);
        }

    }

}

==> webservices-osgi-4.0.3-sources.jar: com/sun/xml/ws/resources/BindingApiMessages.java <==
/*
 * Copyright (c) 1997, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package com.sun.xml.ws.resources;

import java.util.Locale;
import java.util.ResourceBundle;
import com.sun.istack.localization.Localizable;
import com.sun.istack.localization.LocalizableMessageFactory;
import com.sun.istack.localization.LocalizableMessageFactory.ResourceBundleSupplier;
import com.sun.istack.localization.Localizer;


/**
 * Defines string formatting method for each constant in the resource file
 * 
 */
public final class BindingApiMessages {

    private static final String BUNDLE_NAME = "com.sun.xml.ws.resources.bindingApi";
    private static final LocalizableMessageFactory MESSAGE_FACTORY = new LocalizableMessageFactory(BUNDLE_NAME, new BindingApiMessages.BundleSupplier());
    private static final Localizer LOCALIZER = new Localizer();

    private BindingApiMessages() {
    }

    public static Localizable localizableBINDING_API_NO_FAULT_MESSAGE_NAME() {
        return MESSAGE_FACTORY.getMessage("binding.api.no.fault.message.name");
    }

    /**
     * Fault message name must not be null.
     * 
     */
    public static String BINDING_API_NO_FAULT_MESSAGE_NAME() {
        return LOCALIZER.localize(localizableBINDING_API_NO_FAULT_MESSAGE_NAME());
    }

    private static class BundleSupplier
        implements ResourceBundleSupplier
    {


        public ResourceBundle getResourceBundle(Locale locale) {
            return ResourceBundle.getBundle(BUNDLE_NAME, locale);
        }

    }

}
